---
name: New Categorization
about: Propose a new terminology or categorization for inclusion

---

**Describe the categorization**

What kind of thing (gas, area, industry, etc.) is categorized?
Is the categorization hierarchical?
Are there multiple versions?

**References**

Where can the source for the categorization be found?
Are there already machine-readable descriptions available?

**Connection to climate (policy) science**

Why should the categorization be included into climate_categories?

**Additional information**

Other information that can be helpful.
